@@ -31,3 +31,10 @@ class TestMetromobilite:
             r.get(self.m.API_BASE_URL + 'routers/default/index/stops/' + stop_id + '/stoptimes' , json="""{"test": "test"}""")
             response = self.m.get_stoptimes(stop_id)
             assert """{"test": "test"}""" == response
+
+    def test_get_lines_near(self):
+        with requests_mock.Mocker() as r:
+            r.get(self.m.API_BASE_URL + 'api/linesNear/json', json="""{"test": "test"}""")
+            response = self.m.get_lines_near(latitude='test', longitude='test', dist='test', details='test')
+            assert """{"test": "test"}""" == response
+
